/*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"angl"
    "e\",\"range_mean\",\"amplitude_mean\"],\"title\":\"Angular Notch "
    "Filter\",\"description\":\"Angular notch filter parameters for window "
    "glass echoes\",\"properties\":{\"amplitude_mean\":{\"items\":{\"type\":\"number\""
    "},\"description\":\"Mean amplitude [dB]\",\"type\":\"array\"},\"angle\":{\"items\""
    ":{\"type\":\"number\"},\"description\":\"Angle [deg]\",\"type\":\"array\"},\"range_"
    "mean\":{\"items\":{\"type\":\"number\"},\"description\":\"Mean range "
    "[m]\",\"type\":\"array\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,2.850913,2.7209"
    "13,2.680913,2.610913,2.530913,2.570913,2.570913],\"angle\":[14.0,15.0,16"
    ".0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],\"range_mean\":[0.094,0.094,"
    "0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"temp"
    "erature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"amsl\",\"group_velocit"
    "y\",\"attenuation\",\"wavelength\"],\"title\":\"Atmospheric "
    "Parameters\",\"description\":\"Atmospheric "
    "parameters\",\"properties\":{\"pressure_sl\":{\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\",\"type\":\"number\"},\"amsl\":{\"description\":\"Height above mean sea "
    "level (AMSL) [m]\",\"type\":\"number\"},\"wavelength\":{\"description\":\"Laser "
    "wavelength "
    "[nm]\",\"type\":\"number\"},\"attenuation\":{\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\",\"type\":\"number\"},\"temperature\":{\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\",\"type\":\"number\"},\"pressure\":{\"description\":\"Pressure along "
    "measurment path "
    "[mbar]\",\"type\":\"number\"},\"rel_humidity\":{\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\",\"type\":\"number\"},\"group_velocity\":{\"description\":\"Group velocity "
    "of laser beam [m/s]\",\"type\":\"number\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"pressure_sl\":970,\"amsl\":0,\"wavelength\":1550,\"attenuation\":0.028125,\""
    "temperature\":7,\"pressure\":970,\"rel_humidity\":63,\"group_velocity\":29971"
    "1000.0}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"beam"
    "_exit_diameter\",\"beam_divergence\"],\"title\":\"Beam "
    "Geometry\",\"description\":\"Laser beam geometry details\",\"properties\":{\"b"
    "eam_divergence\":{\"exclusiveMinimum\":false,\"description\":\"Beam "
    "divergence in far field [rad]\",\"type\":\"number\",\"minimum\":0},\"beam_exit"
    "_diameter\":{\"exclusiveMinimum\":false,\"description\":\"Beam width at exit"
    " aperture [m]\",\"type\":\"number\",\"minimum\":0}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"beam_divergence\":0.0003,\"beam_exit_diameter\":0.0072}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"type"
    "s\"],\"title\":\"Control Object Catalog\",\"description\":\"List of control "
    "object type definitions\",\"properties\":{\"types\":{\"uniqueItems\":true,\"it"
    "ems\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/rectangle\"},{\"$r"
    "ef\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/definitions/chevron\"},"
    "{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/definitions/cylinder"
    "\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/definitions/round_corner"
    "_cube_prism\"}]},\"type\":\"array\"}},\"type\":\"object\",\"definitions\":{\"chevr"
    "on\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"description\":\"chevron "
    "specific properties\",\"properties\":{\"outside_edge_length\":{\"exclusiveMi"
    "nimum\":true,\"description\":\"length of the two outer edges in meters\",\"t"
    "ype\":\"number\",\"minimum\":0},\"thickness\":{\"exclusiveMinimum\":true,\"descr"
    "iption\":\"thickness in "
    "meters\",\"type\":\"number\",\"minimum\":0},\"shape\":{\"description\":\"shape ide"
    "ntifier\",\"type\":\"string\",\"enum\":[\"chevron\"]}},\"type\":\"object\",\"require"
    "d\":[\"shape\",\"outside_edge_length\",\"thickness\"]}],\"description\":\"chevro"
    "n\",\"type\":\"object\"},\"common\":{\"description\":\"common object "
    "properties\",\"properties\":{\"surface_type\":{\"description\":\"surface "
    "material type\",\"type\":\"string\",\"enum\":[\"retro_reflective_foil\",\"diffus"
    "e\"]},\"description\":{\"description\":\"string describing the "
    "object\",\"type\":\"string\"},\"name\":{\"minLength\":3,\"description\":\"unique "
    "type identifier\",\"type\":\"string\"},\"shape\":{\"description\":\"shape identi"
    "fier\",\"type\":\"string\",\"enum\":[\"rectangle\",\"checkerboard2x2\",\"chevron\","
    "\"circular_disk\",\"cylinder\",\"sphere\",\"round_corner_cube_prism\"]}},\"type"
    "\":\"object\",\"required\":[\"name\",\"shape\"]},\"checkerboard2x2\":{\"allOf\":[{\""
    "$ref\":\"#/definitions/common\"},{\"description\":\"checkerboard specific pr"
    "operties\",\"properties\":{\"square_length\":{\"exclusiveMinimum\":true,\"desc"
    "ription\":\"length of a square of the checkerboard in "
    "meters\",\"type\":\"number\",\"minimum\":0},\"shape\":{\"description\":\"shape ide"
    "ntifier\",\"type\":\"string\",\"enum\":[\"checkerboard2x2\"]}},\"type\":\"object\","
    "\"required\":[\"shape\",\"square_length\"]}],\"description\":\"checkerboard 2 "
    "by 2\",\"type\":\"object\"},\"round_corner_cube_prism\":{\"allOf\":[{\"$ref\":\"#/"
    "definitions/common\"},{\"description\":\"round corner cube prism specific "
    "properties\",\"properties\":{\"diameter\":{\"exclusiveMinimum\":true,\"descrip"
    "tion\":\"diameter in "
    "meters\",\"type\":\"number\",\"minimum\":0},\"offset\":{\"description\":\"offset "
    "in meters, e.g. reflector constant "
    "(optional)\",\"type\":\"number\"},\"shape\":{\"description\":\"shape identifier\""
    ",\"type\":\"string\",\"enum\":[\"round_corner_cube_prism\"]}},\"type\":\"object\","
    "\"required\":[\"shape\",\"diameter\"]}],\"description\":\"round corner cube pri"
    "sm\",\"type\":\"object\"},\"cylinder\":{\"allOf\":[{\"$ref\":\"#/definitions/commo"
    "n\"},{\"description\":\"cylinder specific properties\",\"properties\":{\"diame"
    "ter\":{\"exclusiveMinimum\":true,\"description\":\"diameter in "
    "meters\",\"type\":\"number\",\"minimum\":0},\"shape\":{\"description\":\"shape ide"
    "ntifier\",\"type\":\"string\",\"enum\":[\"cylinder\"]},\"height\":{\"exclusiveMini"
    "mum\":true,\"description\":\"height in meters\",\"type\":\"number\",\"minimum\":0"
    "}},\"type\":\"object\",\"required\":[\"shape\",\"diameter\",\"height\"]}],\"descrip"
    "tion\":\"cylinder\",\"type\":\"object\"},\"rectangle\":{\"allOf\":[{\"$ref\":\"#/def"
    "initions/common\"},{\"description\":\"rectangle specific properties\",\"prop"
    "erties\":{\"width\":{\"exclusiveMinimum\":true,\"description\":\"width in mete"
    "rs\",\"type\":\"number\",\"minimum\":0},\"length\":{\"exclusiveMinimum\":true,\"de"
    "scription\":\"length in meters\",\"type\":\"number\",\"minimum\":0},\"shape\":{\"e"
    "num\":[\"rectangle\"],\"type\":\"string\"}},\"type\":\"object\",\"required\":[\"shap"
    "e\",\"length\",\"width\"]}],\"description\":\"rectangle\",\"type\":\"object\"},\"sph"
    "ere\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"description\":\"sphere "
    "specific properties\",\"properties\":{\"diameter\":{\"exclusiveMinimum\":true"
    ",\"description\":\"diameter in "
    "meters\",\"type\":\"number\",\"minimum\":0},\"shape\":{\"description\":\"shape ide"
    "ntifier\",\"type\":\"string\",\"enum\":[\"sphere\"]}},\"type\":\"object\",\"required"
    "\":[\"shape\",\"diameter\"]}],\"description\":\"sphere\",\"type\":\"object\"},\"circ"
    "ular_disk\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"description\":\"c"
    "ircular disk specific properties\",\"properties\":{\"diameter\":{\"exclusive"
    "Minimum\":true,\"description\":\"diameter in "
    "meters\",\"type\":\"number\",\"minimum\":0},\"offset\":{\"description\":\"offset "
    "in meters, e.g. reflector constant "
    "(optional)\",\"type\":\"number\"},\"shape\":{\"description\":\"shape identifier\""
    ",\"type\":\"string\",\"enum\":[\"circular_disk\"]}},\"type\":\"object\",\"required\""
    ":[\"shape\",\"diameter\"]}],\"description\":\"circular "
    "disk\",\"type\":\"object\"}}}"
    ,
    /* example: */
    "{\"types\":[{\"width\":0.3,\"length\":0.6,\"description\":\"Rectangle (60cm x "
    "30cm)\",\"name\":\"Rectangle 60x30\",\"shape\":\"rectangle\"},{\"width\":0.4,\"len"
    "gth\":0.8,\"description\":\"Rectangle (80cm x 40cm)\",\"name\":\"Rectangle 80x"
    "40\",\"shape\":\"rectangle\"},{\"square_length\":0.3,\"description\":\"Checkerbo"
    "ard (square length: 30cm)\",\"name\":\"Checkerboard2x2 30\",\"shape\":\"checke"
    "rboard2x2\"},{\"square_length\":0.5,\"description\":\"Checkerboard (square "
    "length: 50cm)\",\"name\":\"Checkerboard2x2 50\",\"shape\":\"checkerboard2x2\"},"
    "{\"outside_edge_length\":0.6096,\"thickness\":0.1016,\"description\":\"Chevro"
    "n (a=24''; b=4'')\",\"name\":\"Chevron 24''/4''\",\"shape\":\"chevron\"},{\"diam"
    "eter\":0.5,\"surface_type\":\"diffuse\",\"description\":\" Circular Disk "
    "(diameter: 50cm)\",\"name\":\"Circular Disk "
    "50\",\"shape\":\"circular_disk\"},{\"diameter\":0.05,\"name\":\"RIEGL flat "
    "reflector 50 "
    "mm\",\"surface_type\":\"retro_reflective_foil\",\"description\":\"flat "
    "circular reflector from retro-reflective foil\",\"offset\":0.0,\"shape\":\"c"
    "ircular_disk\"},{\"diameter\":0.1,\"name\":\"RIEGL flat reflector 100 "
    "mm\",\"surface_type\":\"retro_reflective_foil\",\"description\":\"flat "
    "circular reflector from retro-reflective foil\",\"offset\":0.0,\"shape\":\"c"
    "ircular_disk\"},{\"diameter\":0.15,\"name\":\"RIEGL flat reflector 150 "
    "mm\",\"surface_type\":\"retro_reflective_foil\",\"description\":\"flat "
    "circular reflector from retro-reflective foil\",\"offset\":0.0,\"shape\":\"c"
    "ircular_disk\"},{\"diameter\":0.05,\"name\":\"RIEGL cylindrical reflector 50"
    " mm\",\"height\":0.05,\"surface_type\":\"retro_reflective_foil\",\"description"
    "\":\"cylindrical reflector from retro-reflective "
    "foil\",\"shape\":\"cylinder\"},{\"diameter\":0.1,\"name\":\"RIEGL cylindrical "
    "reflector 100 mm\",\"height\":0.1,\"surface_type\":\"retro_reflective_foil\","
    "\"description\":\"cylindrical reflector from retro-reflective "
    "foil\",\"shape\":\"cylinder\"},{\"diameter\":0.2,\"description\":\"Sphere "
    "(diameter: 200 mm)\",\"name\":\"Sphere 200 "
    "mm\",\"shape\":\"sphere\"},{\"diameter\":0.05,\"description\":\"round corner "
    "cube prism\",\"offset\":0.0,\"name\":\"Corner Cube Prism 50 "
    "mm\",\"shape\":\"round_corner_cube_prism\"}],\"comments\":[\"This file "
    "contains a list of control object types (aka. 'catalog').\",\"Each type "
    "is described by an object,\",\"which must contain at least the following"
    " parameters:\",\"  - name: unique identifier of the type\",\"  - shape: "
    "one of the following supported shapes:\",\"      - rectangle\",\"      - "
    "checkerboard2x2\",\"      - chevron\",\"      - circular_disk\",\"      - "
    "cylinder\",\"      - sphere\",\"      - "
    "round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Control Object Reference file\",\"description\":\"Details about "
    "the control object reference "
    "file\",\"properties\":{\"reference_file\":{\"description\":\"Reference to a "
    "control object file\",\"properties\":{\"file_path\":{\"description\":\"Path of"
    " the control object file relative to referring "
    "file\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC 4122)\",\"type\":\"string\"}},\"ty"
    "pe\":\"object\",\"required\":[\"file_uuid\",\"file_path\"]}},\"type\":\"object\",\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoi"
    "nts.cpx\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ampl"
    "itude\",\"detection_probability\"],\"title\":\"Detection "
    "Probability\",\"description\":\"Detection probability as a function of amp"
    "litude\",\"properties\":{\"detection_probability\":{\"items\":{\"type\":\"number"
    "\"},\"description\":\"Detection probability [0..1]\",\"type\":\"array\"},\"ampli"
    "tude\":{\"items\":{\"type\":\"number\"},\"description\":\"Amplitude "
    "[dB]\",\"type\":\"array\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"devi"
    "ce_type\",\"serial_number\"],\"title\":\"Device "
    "Information\",\"description\":\"Details about the device used to acquire "
    "the point cloud\",\"properties\":{\"device_type\":{\"description\":\"Device "
    "type identifier (e.g. "
    "VZ-400i)\",\"type\":\"string\"},\"channel_text\":{\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel devices)\","
    "\"type\":\"string\"},\"channel_number\":{\"exclusiveMinimum\":false,\"descripti"
    "on\":\"Laser channel number (not defined or 0: single channel device)\",\""
    "type\":\"integer\",\"minimum\":0},\"device_build\":{\"description\":\"Device "
    "build variant\",\"type\":\"string\"},\"serial_number\":{\"description\":\"Device"
    " serial number (e.g. "
    "S2221234)\",\"type\":\"string\"},\"device_name\":{\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\",\"type\":\"string\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"device_type\":\"VZ-400i\",\"channel_text\":\"\",\"channel_number\":0,\"device_"
    "build\":\"\",\"serial_number\":\"S2221234\",\"device_name\":\"Scanner 1\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"prim"
    "ary\"],\"title\":\"Device Geometry\",\"description\":\"Scanner device geometry"
    " details\",\"properties\":{\"secondary\":{\"description\":\"Additional device "
    "geometry structure (optional)\",\"properties\":{\"ID\":{\"items\":{\"type\":\"in"
    "teger\"},\"description\":\"Structure identifier\",\"maxItems\":2,\"type\":\"arra"
    "y\",\"minItems\":2},\"content\":{\"items\":{\"type\":\"number\"},\"description\":\"I"
    "nternal calibration values\",\"type\":\"array\"}},\"type\":\"object\",\"required"
    "\":[\"ID\",\"content\"]},\"primary\":{\"description\":\"Primary device geometry "
    "structure (mandatory)\",\"properties\":{\"ID\":{\"items\":{\"type\":\"integer\"},"
    "\"description\":\"Structure identifier\",\"maxItems\":2,\"type\":\"array\",\"minI"
    "tems\":2},\"content\":{\"items\":{\"type\":\"number\"},\"description\":\"Internal "
    "calibration values\",\"type\":\"array\"}},\"type\":\"object\",\"required\":[\"ID\","
    "\"content\"]},\"amu\":{\"description\":\"Angle Measurement Unit\",\"properties\""
    ":{\"lineCC\":{\"exclusiveMinimum\":false,\"description\":\"Line Circle Count "
    "(number of LSBs per full rotation about line axis)\",\"type\":\"number\",\"m"
    "inimum\":0},\"frameCC\":{\"exclusiveMinimum\":false,\"description\":\"Frame "
    "Circle Count (number of LSBs per full rotation about frame axis)\",\"typ"
    "e\":\"number\",\"minimum\":0}},\"type\":\"object\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"secondary\":{\"ID\":[91,0],\"content\":[0]},\"primary\":{\"ID\":[4,0],\"conten"
    "t\":[0]},\"amu\":{\"lineCC\":124000,\"frameCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"prim"
    "ary\"],\"title\":\"Device Geometry Passive Channel\",\"description\":\"Scanner"
    " passive channel device geometry "
    "details\",\"properties\":{\"primary\":{\"description\":\"Primary device "
    "geometry structure (mandatory)\",\"properties\":{\"ID\":{\"items\":{\"type\":\"i"
    "nteger\"},\"description\":\"Structure identifier\",\"maxItems\":2,\"type\":\"arr"
    "ay\",\"minItems\":2},\"content\":{\"items\":{\"type\":\"number\"},\"description\":\""
    "Internal calibration values\",\"type\":\"array\"}},\"type\":\"object\",\"require"
    "d\":[\"ID\",\"content\"]}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"primary\":{\"ID\":[143,0],\"content\":[0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Device Output Limits\",\"description\":\"Limits of the measured "
    "values output by the device. The limits depend on the device type, "
    "measurement program and/or scan pattern.\",\"properties\":{\"background_ra"
    "diation_minimum\":{\"description\":\"Minimum possible background radiation"
    ".\",\"type\":\"number\"},\"reflectance_maximum\":{\"description\":\"Maximum "
    "possible reflectance in "
    "dB.\",\"type\":\"number\"},\"amplitude_minimum\":{\"description\":\"Minimum "
    "possible amplitude in "
    "dB.\",\"type\":\"number\"},\"echo_count_maximum\":{\"description\":\"Maximum "
    "number of echoes a laser shot can "
    "have.\",\"type\":\"number\"},\"deviation_maximum\":{\"description\":\"Maximum "
    "possible pulse shape deviation.\",\"type\":\"number\"},\"amplitude_maximum\":"
    "{\"description\":\"Maximum possible amplitude in "
    "dB.\",\"type\":\"number\"},\"range_maximum\":{\"description\":\"Maximum possible"
    " range in "
    "meters.\",\"type\":\"number\"},\"deviation_minimum\":{\"description\":\"Minimum "
    "possible pulse shape deviation.\",\"type\":\"number\"},\"mta_zone_count_maxi"
    "mum\":{\"description\":\"Maximum number of MTA zones.\",\"type\":\"number\"},\"b"
    "ackground_radiation_maximum\":{\"description\":\"Maximum possible "
    "background "
    "radiation.\",\"type\":\"number\"},\"range_minimum\":{\"description\":\"Minimum "
    "possible range in meters.\",\"type\":\"number\"},\"reflectance_minimum\":{\"de"
    "scription\":\"Minimum possible reflectance in dB.\",\"type\":\"number\"}},\"ty"
    "pe\":\"object\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"background_radiation_minimum\":0,\"mta_zone_count_maximum\":7,\"amplitud"
    "e_minimum\":0.0,\"deviation_maximum\":32767,\"deviation_minimum\":-1,\"ampli"
    "tude_maximum\":100.0,\"reflectance_maximum\":100.0,\"background_radiation_"
    "maximum\":0,\"range_maximum\":10000.0,\"range_minimum\":2.9,\"reflectance_mi"
    "nimum\":-100.0}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Devices Information\",\"items\":{\"properties\":{\"device_type\":{\""
    "description\":\"Device type identifier (e.g. "
    "VZ-400i)\",\"type\":\"string\"},\"channel_text\":{\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel devices)\","
    "\"type\":\"string\"},\"channel_number\":{\"exclusiveMinimum\":false,\"descripti"
    "on\":\"Laser channel number (not defined or 0: single channel "
    "device)\",\"type\":\"integer\",\"minimum\":0},\"signed\":{\"description\":\"Flag "
    "that is set when the original 'riegl.device' entry in the source file "
    "was correctly "
    "signed.\",\"type\":\"boolean\"},\"device_build\":{\"description\":\"Device build"
    " variant\",\"type\":\"string\"},\"serial_number\":{\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\",\"type\":\"string\"},\"device_name\":{\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner systems)\",\"type\":\"stri"
    "ng\"}},\"type\":\"object\",\"required\":[\"device_type\",\"serial_number\"]},\"des"
    "cription\":\"Details about the devices used to acquire the point cloud "
    "(e.g. when merging point clouds of different devices)\",\"type\":\"array\","
    "\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "[{\"device_type\":\"VZ-400i\",\"channel_text\":\"\",\"channel_number\":0,\"signed"
    "\":false,\"device_build\":\"\",\"serial_number\":\"S2221234\",\"device_name\":\"Sc"
    "anner 1\"},{\"device_type\":\"VQ-1560i-DW\",\"channel_text\":\"\",\"channel_numb"
    "er\":1,\"signed\":true,\"device_build\":\"\",\"serial_number\":\"S2222680\",\"devi"
    "ce_name\":\"Scanner 2\"},{\"device_type\":\"VQ-1560i-DW\",\"channel_text\":\"\",\""
    "channel_number\":2,\"signed\":true,\"device_build\":\"\",\"serial_number\":\"S22"
    "22680\",\"device_name\":\"Scanner 3\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Dyntrig\",\"description\":\"Dyntrig\",\"properties\":{\"scale\":{\"des"
    "cription\":\"Scale in units of dB, for calculation of line: line number "
    "N=(amplitude-offset)/scale\",\"type\":\"number\"},\"post\":{\"description\":\"Dy"
    "ntrig post values\",\"properties\":{\"a\":{\"items\":{\"type\":\"number\"},\"minIt"
    "ems\":1,\"type\":\"array\",\"maxItems\":2080,\"description\":\"...\"},\"nc\":{\"maxi"
    "mum\":255,\"minimum\":0,\"type\":\"integer\",\"description\":\"Number of entries"
    "\"}},\"type\":\"object\",\"required\":[\"nc\",\"a\"]},\"tab\":{\"items\":{\"descriptio"
    "n\":\"...\",\"properties\":{\"thra2\":{\"description\":\"Pre-trigger threshold "
    "in units of dB\",\"type\":\"number\"},\"del2\":{\"description\":\"Length of "
    "constant pre-trigger threshold elevation in units of "
    "m\",\"type\":\"number\"},\"dec1\":{\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\",\"type\":\"number\"},\"thra1\":{\"description\":\"Post-trigger threshold "
    "in units of dB\",\"type\":\"number\"},\"del1\":{\"description\":\"Length of "
    "constant post-trigger threshold elevation in units of "
    "m\",\"type\":\"number\"},\"dec2\":{\"description\":\"Rise of pre-trigger "
    "threshold after del2 in units of dB/m\",\"type\":\"number\"}},\"type\":\"objec"
    "t\",\"required\":[\"thra1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"]},\"minItems"
    "\":1,\"type\":\"array\",\"maxItems\":128,\"description\":\"...\"},\"offset\":{\"desc"
    "ription\":\"Offset in units of dB, for calculation of "
    "line\",\"type\":\"number\"},\"pre\":{\"description\":\"Dyntrig pre values\",\"prop"
    "erties\":{\"a\":{\"items\":{\"type\":\"number\"},\"minItems\":1,\"type\":\"array\",\"m"
    "axItems\":2080,\"description\":\"...\"},\"nc\":{\"maximum\":255,\"minimum\":0,\"ty"
    "pe\":\"integer\",\"description\":\"Number of entries\"}},\"type\":\"object\",\"req"
    "uired\":[\"nc\",\"a\"]}},\"$schema\":\"http://json-schema.org/draft-04/schema#"
    "\"}"
    ,
    /* example: */
    "{\"scale\":1.0,\"post\":{\"a\":[78,86,126,134,31],\"nc\":128},\"tab\":[{\"thra2\":"
    "0.0,\"del2\":0.0,\"dec1\":0.0,\"thra1\":0.0,\"del1\":0.0,\"dec2\":0.0}],\"offset\""
    ":0.0,\"pre\":{\"a\":[78,86,126,134,31],\"nc\":128}}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"echo"
    "_file\"],\"title\":\"Echo Information\",\"description\":\"Details about echo f"
    "iles\",\"properties\":{\"echo_file\":{\"properties\":{\"file_extension\":{\"desc"
    "ription\":\"Echo file extension, without the leading "
    "dot\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\",\"type\":\"string\"}},\"type\":\"object\",\"requi"
    "red\":[\"file_extension\"]}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_extension\":\"owp\",\"file_uuid\":\"26a03615-67c0-4bea-8"
    "fe8-c577378fe661\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"patternPropertie"
    "s\":{\"^[0-9]+$\":{\"description\":\"one field per channel, field name is "
    "channel index\",\"$ref\":\"#/definitions/channel\"}},\"title\":\"Exponential "
    "Decomposition\",\"additionalProperties\":false,\"description\":\"Details for"
    " exponential decomposition of full waveform data\",\"type\":\"object\",\"def"
    "initions\":{\"channel\":{\"properties\":{\"scale\":{\"description\":\"amplitude "
    "calibration\",\"type\":\"number\"},\"parameter\":{\"description\":\"parameters "
    "of the syswave exponential sum\",\"properties\":{\"B\":{\"items\":{\"type\":\"nu"
    "mber\"},\"description\":\"imaginary part of amplitude factor in units of f"
    "ull-scale\",\"type\":\"array\"},\"gamma\":{\"items\":{\"type\":\"number\"},\"descrip"
    "tion\":\"decay in 1/second\",\"type\":\"array\"},\"omega\":{\"items\":{\"type\":\"nu"
    "mber\"},\"description\":\"angular frequency in "
    "Hz\",\"type\":\"array\"},\"A\":{\"items\":{\"type\":\"number\"},\"description\":\"real"
    " part of amplitude factor in units of full-scale\",\"type\":\"array\"}},\"ty"
    "pe\":\"object\",\"required\":[\"A\",\"B\",\"gamma\",\"omega\"]},\"delay\":{\"descripti"
    "on\":\"delay calibration in seconds\",\"type\":\"number\"},\"a_lin\":{\"exclusiv"
    "eMinimum\":false,\"maximum\":1,\"exclusiveMaximum\":false,\"description\":\"re"
    "lative linear amplitude range [0..1]\",\"type\":\"number\",\"minimum\":0}},\"t"
    "ype\":\"object\",\"required\":[\"delay\",\"scale\",\"parameter\"]}}}"
    ,
    /* example: */
    "{\"1\":{\"scale\":1.0,\"parameter\":{\"B\":[-3.9,0.0,-0.3],\"gamma\":[-109472652"
    "8.0,-769562752.0,-848000064.0],\"omega\":[352020896.0,3647927552.0,-1977"
    "987072.0],\"A\":[0.9,0.3,-1.3]},\"delay\":3.5e-09,\"a_lin\":0.9},\"0\":{\"scale"
    "\":1.0,\"parameter\":{\"B\":[-3.9813032150268555,0.08622030913829803,-0.315"
    "2860999107361],\"gamma\":[-1094726528.0,-769562752.0,-848000064.0],\"omeg"
    "a\":[352020896.0,3647927552.0,-1977987072.0],\"A\":[0.9772450923919678,0."
    "3354335129261017,-1.312678575515747]},\"delay\":3.783458418887631e-09,\"a"
    "_lin\":0.27}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ampl"
    "itude_lsb_low_power\",\"amplitude_lsb_high_power\",\"amplitude_db\",\"range_"
    "offset_sec_low_power\",\"range_offset_sec_high_power\"],\"title\":\"Gaussian"
    " Decomposition\",\"description\":\"riegl.gaussian_decomposition contains "
    "information relevant for extracting calibrated amplitudes and "
    "calibrated ranges from a Gaussian decomposition of full waveform data."
    " This information is contained in a table with five columns. Two "
    "columns are to be used as input: amplitude_lsb_low_power and "
    "amplitude_lsb_high_power. The other three columns provide the outputs."
    " Amplitude_db gives the calibrated amplitude in the optical regime in "
    "decibels. The range offset columns provide additive range offsets, "
    "given in units of seconds, for each channel.\",\"properties\":{\"amplitude"
    "_lsb_high_power\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude"
    "_db\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"range_offset_sec_low_"
    "power\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"range_offset_sec_hi"
    "gh_power\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_lsb_lo"
    "w_power\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude_lsb_high_power\":[],\"amplitude_db\":[],\"range_offset_sec_low"
    "_power\":[],\"range_offset_sec_high_power\":[],\"amplitude_lsb_low_power\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Geo Tag\",\"description\":\"Point cloud georeferencing informati"
    "on\",\"properties\":{\"pose\":{\"items\":{\"items\":{\"description\":\"columns\",\"t"
    "ype\":\"number\"},\"description\":\"rows\",\"type\":\"array\",\"maxItems\":4,\"minIt"
    "ems\":4},\"description\":\"Coordinate Transformation Matrix to transform "
    "from File Coordinate System to Global Coordinate Reference System. 4x4"
    " matrix stored as two dimensional array, row major order.\",\"type\":\"arr"
    "ay\",\"maxItems\":4,\"minItems\":4},\"crs\":{\"description\":\"Global Coordinate"
    " Reference System. Please note that only 3D Cartesian Coordinate "
    "Systems are allowed.\",\"properties\":{\"wkt\":{\"description\":\"\\\"Well-Known"
    " Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.org/sta"
    "ndards/wkt-crs)\",\"type\":\"string\"},\"name\":{\"description\":\"Coordinate "
    "reference system name\",\"type\":\"string\"},\"epsg\":{\"description\":\"EPSG co"
    "de\",\"type\":\"integer\",\"minimum\":0}},\"type\":\"object\"}},\"type\":\"object\",\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063"
    "882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113"
    "8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0"
    ".0,0.0,0.0,1.0]],\"crs\":{\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS"
    "84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\"
    "\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000"
    "000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.0000000000000"
    "0000000,AUTHORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAS"
    "T],AXIS[\\\"Z\\\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"name\":\"WGS84 "
    "Geocentric\",\"epsg\":4978}}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"Geometric scale "
    "factor applied to point coordinates\",\"type\":\"number\",\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Georeferencing Parameters\",\"description\":\"Parameters used "
    "for georeferencing of the point "
    "cloud\",\"properties\":{\"trajectory_offsets\":{\"description\":\"Correction "
    "offsets applied to the trajectory data\",\"properties\":{\"offset_time\":{\""
    "description\":\"[s]\",\"type\":\"number\"},\"offset_pitch\":{\"description\":\"[de"
    "g]\",\"type\":\"number\"},\"offset_roll\":{\"description\":\"[deg]\",\"type\":\"numb"
    "er\"},\"offset_yaw\":{\"description\":\"[deg]\",\"type\":\"number\"},\"offset_nort"
    "h\":{\"description\":\"[m]\",\"type\":\"number\"},\"offset_east\":{\"description\":"
    "\"[m]\",\"type\":\"number\"},\"offset_height\":{\"description\":\"[m]\",\"type\":\"nu"
    "mber\"},\"version\":{\"description\":\"Meaning of offset values and how to "
    "apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\",\"type\":\"integer\"}},\"type\":\"object\"},\"socs_to_rocs_m"
    "atrix\":{\"items\":{\"items\":{\"description\":\"columns\",\"type\":\"number\"},\"de"
    "scription\":\"rows\",\"type\":\"array\",\"maxItems\":4,\"minItems\":4},\"descripti"
    "on\":\"Coordinate Transformation Matrix to transform from Scanner's Own "
    "Coordinate System to Record Coordinate System. 4x4 matrix stored as "
    "two dimensional array, row major order.\",\"type\":\"array\",\"maxItems\":4,\""
    "minItems\":4},\"body_coordinate_system_type\":{\"description\":\"BODY "
    "coordinate frame (NED: North-East-Down, ENU: East-North-Up), default: "
    "NED\",\"type\":\"string\",\"enum\":[\"NED\",\"ENU\"]},\"socs_to_body_matrix\":{\"ite"
    "ms\":{\"items\":{\"description\":\"columns\",\"type\":\"number\"},\"description\":\""
    "rows\",\"type\":\"array\",\"maxItems\":4,\"minItems\":4},\"description\":\"Coordin"
    "ate Transformation Matrix to transform from Scanner's Own Coordinate "
    "System to Body Coordinate System. 4x4 matrix stored as two dimensional"
    " array, row major order.\",\"type\":\"array\",\"maxItems\":4,\"minItems\":4},\"t"
    "rajectory_file\":{\"description\":\"Trajectory data used for "
    "georeferencing of the point "
    "cloud\",\"properties\":{\"file_extension\":{\"description\":\"Trajectory file "
    "extension, without the leading "
    "dot\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\",\"type\":\"string\"}},\"type\":\"object\",\"requi"
    "red\":[\"file_extension\"]}},\"type\":\"object\",\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"trajectory_offsets\":{\"offset_time\":18.007,\"offset_pitch\":0.01,\"offse"
    "t_roll\":0.03,\"offset_yaw\":-0.45,\"offset_north\":0.07,\"offset_east\":0.15"
    ",\"offset_height\":-0.2,\"version\":0},\"body_coordinate_system_type\":\"NED\""
    ",\"socs_to_body_matrix\":[[-0.269827776749716,-0.723017716139738,0.63595"
    "4678449952,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",0.0],[0.0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],\""
    "trajectory_file\":{\"file_extension\":\"pofx\",\"file_uuid\":\"93a03615-66c0-4"
    "bea-8ff8-c577378fe660\"}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"patternPropertie"
    "s\":{\"^-?[0-9]+$\":{\"description\":\"One field per item, field name is "
    "item id, field value is item name\",\"type\":\"string\"}},\"title\":\"Item "
    "Names\",\"additionalProperties\":false,\"description\":\"Map of item "
    "names\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"1\":\"Name of item with id 1\",\"47\":\"Name of item with id 47\",\"2\":\"Name"
    " of item with id 2\",\"-1\":\"Name of item with id -1\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"patternPropertie"
    "s\":{\"^.*$\":{\"items\":{\"description\":\"License key (example: '46AE032A - "
    "39882AC4 - 9EC0A184 - 6F163D73')\",\"type\":\"string\"},\"description\":\"Each"
    " field of the object represents a feature and holds a list of license "
    "keys, where the field name is the feature "
    "name.\",\"type\":\"array\",\"minItems\":1}},\"title\":\"Software License "
    "Keys\",\"additionalProperties\":false,\"description\":\"License keys for "
    "software features\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography with GPU support\":[\"8AB44126 - "
    "23B92250 - 16E2689F - 34EF7E7B\"],\"MTA resolution\":[\"468E020A - "
    "39A922E4 - B681A184 - 673E3D72\"],\"Georeferencing\":[\"46AE032A - "
    "39882AC4 - 9EC0A184 - 6F163D73\"],\"Full Waveform Analysis "
    "Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA - 8D2ED557\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"MTA Settings\",\"description\":\"Parameters for MTA processing\","
    "\"properties\":{\"zone_count\":{\"maximum\":255,\"description\":\"Maximum "
    "number of MTA zones.\",\"type\":\"integer\",\"minimum\":0},\"modulation_depth\""
    ":{\"description\":\"Depth of pulse position modulation in meter.\",\"type\":"
    "\"number\",\"minimum\":0},\"zone_width\":{\"description\":\"Width of a MTA zone"
    " in meter.\",\"type\":\"number\",\"minimum\":0}},\"type\":\"object\",\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"zone_count\":23,\"modulation_depth\":9.368514,\"zone_width\":149.896225}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"delt"
    "a\",\"content\"],\"title\":\"Near Range Correction "
    "Table\",\"description\":\"Lookup table for range correction based on raw "
    "range\",\"properties\":{\"delta\":{\"description\":\"Delta between table "
    "entries [m], first entry is at range = 0 m\",\"type\":\"number\"},\"content\""
    ":{\"items\":{\"type\":\"number\"},\"description\":\"Correction value [m] to be "
    "added to the raw "
    "range\",\"maxItems\":2000,\"type\":\"array\",\"minItems\":1}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ampl"
    "itude\",\"range_sigma\",\"amplitude_sigma\"],\"title\":\"Noise "
    "Estimates\",\"description\":\"Standard deviation for range and amplitude "
    "as a function of amplitude\",\"properties\":{\"amplitude_sigma\":{\"items\":{"
    "\"type\":\"number\"},\"description\":\"Sigma amplitude [dB]\",\"type\":\"array\"},"
    "\"range_sigma\":{\"items\":{\"type\":\"number\"},\"description\":\"Sigma range [m"
    "]\",\"type\":\"array\"},\"amplitude\":{\"items\":{\"type\":\"number\"},\"description"
    "\":\"Amplitude [dB]\",\"type\":\"array\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.4"
    "32,0.39,0.354],\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.02"
    "4,0.021,0.018,0.016,0.014],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7."
    "0,8.0,9.0,10.0]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"rang"
    "e_minimum\",\"range_maximum\",\"amplitude_maximum\"],\"title\":\"Notch "
    "Filter\",\"description\":\"Notch filter parameters for window glass echoes"
    "\",\"properties\":{\"amplitude_maximum\":{\"minimum\":0,\"type\":\"number\",\"desc"
    "ription\":\"Maximum amplitude "
    "[dB]\"},\"range_maximum\":{\"description\":\"Maximum range "
    "[m]\",\"type\":\"number\"},\"range_minimum\":{\"description\":\"Minimum range "
    "[m]\",\"type\":\"number\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"amplitude_maximum\":18.0,\"range_maximum\":0.2,\"range_minimum\":-0.5}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"size"
    "\"],\"title\":\"Pixel Information\",\"description\":\"Details about the pixels"
    " contained in the file\",\"properties\":{\"size_llcs\":{\"description\":\"Size"
    " of pixels in a locally levelled cartesian coordinate system (xy). "
    "This is only used for pixels based on a map projection.\",\"$ref\":\"#/def"
    "initions/pixel_size\"},\"size\":{\"description\":\"Size of pixels in file "
    "coordinate system.\",\"$ref\":\"#/definitions/pixel_size\"}},\"type\":\"object"
    "\",\"definitions\":{\"pixel_size\":{\"items\":{\"description\":\"Length of pixel"
    " edge [m].\",\"type\":\"number\",\"minimum\":0},\"description\":\"Size of "
    "pixels.\",\"type\":\"array\",\"maxItems\":2,\"minItems\":2}}}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"plan"
    "e_patch_file_one\",\"plane_patch_file_two\"],\"title\":\"Plane Patch "
    "Matching\",\"description\":\"Details about the plane patch matching proces"
    "s\",\"properties\":{\"plane_patch_file_one\":{\"description\":\"Reference to "
    "the plane patch file one\",\"$ref\":\"#/definitions/file_reference\"},\"plan"
    "e_patch_file_two\":{\"description\":\"Reference to the plane patch file tw"
    "o\",\"$ref\":\"#/definitions/file_reference\"}},\"type\":\"object\",\"definition"
    "s\":{\"file_reference\":{\"description\":\"Reference to a plane patch "
    "file\",\"properties\":{\"file_path\":{\"description\":\"Path of the plane "
    "patch file relative to the match "
    "file\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"Plane patch file's "
    "Universally Unique Identifier (RFC 4122)\",\"type\":\"string\"}},\"type\":\"ob"
    "ject\",\"required\":[\"file_uuid\",\"file_path\"]}}}"
    ,
    /* example: */
    "{\"plane_patch_file_one\":{\"file_path\":\"Record009_Line001/191025_121410_"
    "Scanner_1.ptch\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"},\"p"
    "lane_patch_file_two\":{\"file_path\":\"project.ptch\",\"file_uuid\":\"fa47d509"
    "-a64e-49ce-8b14-ff3130fbefa9\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Plane Patch Statistics\",\"description\":\"Statistics about "
    "plane patches found by plane patch "
    "extractor\",\"properties\":{\"total_horizontal_area\":{\"description\":\"sum "
    "of all plane patch areas projected to horizontal plane "
    "[m\\u00b2]\",\"type\":\"number\"},\"total_area\":{\"description\":\"sum of all "
    "plane patch areas [m\\u00b2]\",\"type\":\"number\"}},\"type\":\"object\",\"$schem"
    "a\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"total_horizontal_area\":13954.601,\"total_area\":14007.965}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"sett"
    "ings\",\"classes\"],\"title\":\"Plane Slope Class "
    "Info\",\"description\":\"Settings and classes for plane slope classificati"
    "on\",\"properties\":{\"classes\":{\"additionalProperties\":false,\"description"
    "\":\"Class definition table\",\"type\":\"object\",\"patternProperties\":{\"^[0-9"
    "]+$\":{\"description\":\"one field per class, field name is class number, "
    "field value is class "
    "name\",\"type\":\"string\"}}},\"settings\":{\"description\":\"Classification "
    "settings, details see documentation of rdbplanes\",\"type\":\"object\",\"one"
    "Of\":[{\"$ref\":\"#/definitions/method-1\"},{\"$ref\":\"#/definitions/method-2"
    "\"}]}},\"type\":\"object\",\"definitions\":{\"method-1\":{\"description\":\"Classi"
    "fication method 1\",\"properties\":{\"maximum_inclination_angle_horizontal"
    "\":{\"maximum\":360.0,\"description\":\"maximum inclination angle of "
    "horizontal plane patches [deg]\",\"type\":\"number\",\"minimum\":-360.0},\"pla"
    "ne_classification_method\":{\"maximum\":1,\"description\":\"method ID (=1)\","
    "\"type\":\"integer\",\"minimum\":1}},\"type\":\"object\",\"required\":[\"plane_clas"
    "sification_method\",\"maximum_inclination_angle_horizontal\"]},\"method-2\""
    ":{\"description\":\"Classification method 2\",\"properties\":{\"sloping_plane"
    "_classes_minimum_angle\":{\"maximum\":360.0,\"description\":\"minimum "
    "inclination angle of sloping plane patches [deg]\",\"type\":\"number\",\"min"
    "imum\":-360.0},\"sloping_plane_classes_maximum_angle\":{\"maximum\":360.0,\""
    "description\":\"maximum inclination angle of sloping plane patches [deg]"
    "\",\"type\":\"number\",\"minimum\":-360.0},\"plane_classification_method\":{\"ma"
    "ximum\":2,\"description\":\"method ID (=2)\",\"type\":\"integer\",\"minimum\":2}}"
    ",\"type\":\"object\",\"required\":[\"plane_classification_method\",\"sloping_pl"
    "ane_classes_minimum_angle\",\"sloping_plane_classes_maximum_angle\"]}}}"
    ,
    /* example: */
    "{\"classes\":{\"3\":\"sloping, pointing up and south\",\"13\":\"sloping, "
    "pointing down and west\",\"14\":\"horizontal, pointing "
    "down\",\"6\":\"vertical, pointing east\",\"10\":\"sloping, pointing down and "
    "east\",\"12\":\"sloping, pointing down and north\",\"7\":\"vertical, pointing "
    "south\",\"11\":\"sloping, pointing down and south\",\"1\":\"horizontal, "
    "pointing up\",\"8\":\"vertical, pointing north\",\"5\":\"sloping, pointing up "
    "and west\",\"4\":\"sloping, pointing up and north\",\"9\":\"vertical, pointing"
    " west\",\"2\":\"sloping, pointing up and east\"},\"settings\":{\"sloping_plane"
    "_classes_minimum_angle\":10.0,\"sloping_plane_classes_maximum_angle\":70."
    "0,\"plane_classification_method\":2}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"patternPropertie"
    "s\":{\"^.*$\":{\"items\":{\"description\":\"Point attribute full name or name "
    "pattern (perl regular expression "
    "syntax)\",\"type\":\"string\"},\"description\":\"Each field of the object "
    "represents a point attribute group and holds a list of point "
    "attributes, where the field name is the group "
    "name.\",\"type\":\"array\",\"minItems\":1}},\"title\":\"Point Attribute "
    "Groups\",\"additionalProperties\":false,\"description\":\"Grouping and "
    "sorting of point attributes for visualization "
    "purposes\",\"type\":\"object\"}"
    ,
    /* example: */
    "{\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl"
    ".phi\"],\"Other Attributes\":[\"riegl.selected\",\"riegl.visible\"],\"Time\":[\""
    "riegl.timestamp\"],\"Primary Attributes\":[\"riegl.reflectance\",\"riegl.amp"
    "litude\",\"riegl.deviation\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Point Cloud Information\",\"description\":\"Details about point "
    "cloud files\",\"properties\":{\"comments\":{\"description\":\"Comments\",\"type\""
    ":\"string\"},\"project\":{\"description\":\"Project "
    "name\",\"type\":\"string\"},\"field_of_application\":{\"description\":\"Field of"
    " application\",\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS"
    "\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"]}},\"type\":\"object\",\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"comments\":\"Line 3\",\"project\":\"Campaign "
    "4\",\"field_of_application\":\"ALS\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"orie"
    "ntation\"],\"title\":\"Pose Estimation\",\"description\":\"Estimated position "
    "and orientation information as measured by GNSS, IMU or inclination "
    "sensors\",\"properties\":{\"orientation\":{\"description\":\"Orientation "
    "values and orientation accuracies, measured with IMU or inclination se"
    "nsors.\",\"properties\":{\"roll_accuracy\":{\"exclusiveMinimum\":true,\"descri"
    "ption\":\"Roll angle accuracy [deg]\",\"type\":\"number\",\"minimum\":0},\"yaw\":"
    "{\"maximum\":360,\"description\":\"Yaw angle about scanner Z-axis [deg]\",\"t"
    "ype\":\"number\",\"minimum\":-360},\"roll\":{\"maximum\":360,\"description\":\"Rol"
    "l angle about scanner X-axis [deg]\",\"type\":\"number\",\"minimum\":-360},\"y"
    "aw_accuracy\":{\"exclusiveMinimum\":true,\"description\":\"Yaw angle "
    "accuracy [deg]\",\"type\":\"number\",\"minimum\":0},\"pitch_accuracy\":{\"exclus"
    "iveMinimum\":true,\"description\":\"Pitch angle accuracy [deg]\",\"type\":\"nu"
    "mber\",\"minimum\":0},\"pitch\":{\"maximum\":360,\"description\":\"Pitch angle "
    "about scanner Y-axis [deg]\",\"type\":\"number\",\"minimum\":-360}},\"type\":\"o"
    "bject\",\"required\":[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accurac"
    "y\",\"yaw_accuracy\"]},\"position\":{\"description\":\"Position coordinates "
    "and position accuracy values as measured by GNSS in the specified "
    "Coordinate Reference System (CRS)\",\"properties\":{\"horizontal_accuracy\""
    ":{\"exclusiveMinimum\":true,\"description\":\"Horizontal accuracy [m]\",\"typ"
    "e\":\"number\",\"minimum\":0},\"vertical_accuracy\":{\"exclusiveMinimum\":true,"
    "\"description\":\"Vertical accuracy [m]\",\"type\":\"number\",\"minimum\":0},\"co"
    "ordinate_1\":{\"description\":\"Coordinate 1 as defined by axis 1 of the "
    "specified CRS (e.g., X, "
    "Latitude)\",\"type\":\"number\"},\"coordinate_2\":{\"description\":\"Coordinate "
    "2 as defined by axis 2 of the specified CRS (e.g., Y, "
    "Longitude)\",\"type\":\"number\"},\"coordinate_3\":{\"description\":\"Coordinate"
    " 3 as defined by axis 3 of the specified CRS (e.g., Z, "
    "Altitude)\",\"type\":\"number\"},\"crs\":{\"description\":\"Global Coordinate "
    "Reference System\",\"properties\":{\"wkt\":{\"description\":\"\\\"Well-Known "
    "Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.org/stan"
    "dards/wkt-crs)\",\"type\":\"string\"},\"epsg\":{\"description\":\"EPSG code\",\"ty"
    "pe\":\"integer\",\"minimum\":0}},\"type\":\"object\",\"required\":[\"epsg\"]}},\"typ"
    "e\":\"object\",\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3\",\""
    "horizontal_accuracy\",\"vertical_accuracy\",\"crs\"]},\"barometric_height_am"
    "sl\":{\"description\":\"Altitude determined based on the atmospheric "
    "pressure according to the standard atmosphere laws "
    "[m].\",\"type\":\"number\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"orientation\":{\"roll_accuracy\":0.009433783936875745,\"yaw\":101.8729363"
    "0292045,\"roll\":3.14743073066123,\"yaw_accuracy\":1.0094337839368757,\"pit"
    "ch_accuracy\":0.009433783936875745,\"pitch\":1.509153024827064},\"position"
    "\":{\"horizontal_accuracy\":0.810699999332428,\"vertical_accuracy\":1.33149"
    "99341964722,\"coordinate_1\":48.655799473,\"coordinate_2\":15.645033406,\"c"
    "oordinate_3\":362.7124938964844,\"crs\":{\"wkt\":\"GEOGCS[\\\"WGS84 / Geograph"
    "ic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTH"
    "ORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Green"
    "wich\\\",0.0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\"
    "\",0.01745329251994329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude"
    "\\\",NORTH],AXIS[\\\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\",\"eps"
    "g\":4979}},\"barometric_height_amsl\":386.7457796227932}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"gyro"
    "scope\",\"accelerometer\",\"magnetic_field_sensor\"],\"title\":\"Pose "
    "Sensors\",\"description\":\"Details on position and orientation "
    "sensors\",\"properties\":{\"accelerometer\":{\"description\":\"Accelerometer "
    "details\",\"properties\":{\"z_axis\":{\"description\":\"Sensitive Z axis of "
    "sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"description\":\"Sensitive X"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"re"
    "lative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimensionl"
    "ess\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"exclusiveMinimum\":true,\"d"
    "escription\":\"Unit of raw data and calibration values, 1 LSB in 9.81 "
    "m/s\\u00b2\",\"type\":\"number\",\"minimum\":0},\"offset\":{\"description\":\"Value"
    " to be subtracted from raw measurement "
    "values\",\"$ref\":\"#/definitions/vector\"},\"origin\":{\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}},\"t"
    "ype\":\"object\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\""
    "origin\",\"relative_nonlinearity\"]},\"magnetic_field_sensor\":{\"descriptio"
    "n\":\"Magnetic Field Sensor "
    "details\",\"properties\":{\"fixed\":{\"description\":\"Distortion of magnetic "
    "field caused by non-rotating scanner part\",\"$ref\":\"#/definitions/vecto"
    "r\"},\"z_axis\":{\"description\":\"Sensitive Z axis of sensor at frame angle"
    " = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"description\":\"Sensitive X"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"re"
    "lative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimensionl"
    "ess\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"exclusiveMinimum\":true,\"d"
    "escription\":\"Unit of raw data and calibration values, 1 LSB in "
    "nT\",\"type\":\"number\",\"minimum\":0},\"offset\":{\"description\":\"Value to be "
    "subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\"}"
    ",\"y_axis\":{\"description\":\"Sensitive Y axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"}},\"type\":\"object\",\"required\":[\"unit\","
    "\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relative_nonlinearity\"]},"
    "\"gyroscope\":{\"description\":\"Gyroscope "
    "details\",\"properties\":{\"z_axis\":{\"description\":\"Sensitive Z axis of "
    "sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"description\":\"Sensitive X"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"re"
    "lative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimensionl"
    "ess\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"exclusiveMinimum\":true,\"d"
    "escription\":\"Unit of raw data and calibration values, 1 LSB in "
    "rad/s\",\"type\":\"number\",\"minimum\":0},\"offset\":{\"description\":\"Value to "
    "be subtracted from raw measurement "
    "values\",\"$ref\":\"#/definitions/vector\"},\"origin\":{\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}},\"t"
    "ype\":\"object\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\""
    "origin\",\"relative_nonlinearity\"]}},\"type\":\"object\",\"definitions\":{\"vec"
    "tor\":{\"items\":{\"description\":\"Index 0=X, 1=Y, 2=Z component\",\"type\":\"n"
    "umber\"},\"minItems\":3,\"type\":\"array\",\"maxItems\":3}}}"
    ,
    /* example: */
    "{\"accelerometer\":{\"z_axis\":[1.639882206916809,15166.744140625,-116.997"
    "42889404297],\"x_axis\":[-15008.123046875,56.956390380859375,-60.5175666"
    "809082],\"relative_nonlinearity\":[0.0,0.0,0.0],\"unit\":6.666666740784422"
    "e-05,\"offset\":[-733.3636474609375,58.969032287597656,1060.255004882812"
    "5],\"origin\":[0.026900000870227814,-0.03999999910593033,-0.089500002562"
    "99973],\"y_axis\":[-7.027288913726807,-44.12333679199219,14952.370117187"
    "5]},\"magnetic_field_sensor\":{\"fixed\":[-1576.010498046875,1596.08178710"
    "9375,0.0],\"z_axis\":[0.00041987866279669106,7.876977906562388e-05,0.011"
    "407104320824146],\"x_axis\":[-0.011162743903696537,-2.315962774446234e-0"
    "5,0.00016818844596855342],\"relative_nonlinearity\":[0.0,0.0,0.0],\"unit\""
    ":91.74311828613281,\"offset\":[-23812.052734375,5606.57666015625,2493.28"
    "125],\"y_axis\":[0.00027888521435670555,-0.011427424848079681,-5.2048297"
    "22060822e-05]},\"gyroscope\":{\"z_axis\":[0.555869996547699,119.2213516235"
    "3516,0.467585027217865],\"x_axis\":[-121.195556640625,0.8219714164733887"
    ",0.2313031703233719],\"relative_nonlinearity\":[2.888176311444113e-07,1."
    "06274164579645e-07,-1.7186295080634935e-39],\"unit\":0.00014544410805683"
    "583,\"offset\":[-50.92609786987305,146.15643310546875,62.4327278137207],"
    "\"origin\":[0.026900000870227814,-0.03999999910593033,-0.089500002562999"
    "73],\"y_axis\":[-0.440765917301178,-0.7897399663925171,119.5894775390625"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"leng"
    "th\",\"num_mod_ampl\",\"pulse_interval\"],\"title\":\"Pulse Position "
    "Modulation\",\"description\":\"Laser pulse position modulation used for "
    "MTA resolution\",\"properties\":{\"pulse_interval\":{\"items\":{\"minimum\":0,\""
    "type\":\"number\"},\"description\":\"Explicit table of the pulse position "
    "modulation used for MTA resolution. Table gives times between "
    "successive laser pulses in seconds.\",\"type\":\"array\"},\"length\":{\"maximu"
    "m\":255,\"description\":\"Length of code\",\"type\":\"integer\",\"minimum\":0},\"c"
    "ode_phase_mode\":{\"maximum\":255,\"description\":\"0: no synchronization, "
    "1: toggle between 2 phases, 2: increment with phase_increment\",\"type\":"
    "\"integer\",\"minimum\":0},\"num_mod_ampl\":{\"maximum\":255,\"description\":\"Nu"
    "mber of different modulation amplitudes (2: binary modulation)\",\"type\""
    ":\"integer\",\"minimum\":0},\"phase_step\":{\"maximum\":255,\"description\":\"Ste"
    "p width in phase of modulation code from line to "
    "line\",\"type\":\"integer\",\"minimum\":0}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"pulse_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06"
    ",2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.82"
    "1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e"
    "-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2"
    ".759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.8218"
    "75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-0"
    "6],\"length\":31,\"code_phase_mode\":2,\"num_mod_ampl\":2,\"phase_step\":5}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"mini"
    "mum\",\"average\",\"maximum\",\"std_dev\"],\"title\":\"Range "
    "Statistics\",\"description\":\"Statistics about target distance wrt. SOCS "
    "origin\",\"properties\":{\"minimum\":{\"description\":\"Minimum "
    "value\",\"type\":\"number\"},\"std_dev\":{\"description\":\"Standard "
    "deviation\",\"type\":\"number\"},\"maximum\":{\"description\":\"Maximum "
    "value\",\"type\":\"number\"},\"average\":{\"description\":\"Average "
    "value\",\"type\":\"number\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"minimum\":0.919,\"std_dev\":24.349,\"maximum\":574.35,\"average\":15.49738}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Receiver"
    " Internals\",\"description\":\"Receiver Internals\",\"properties\":{\"a\":{\"ite"
    "ms\":{\"type\":\"number\"},\"minItems\":1,\"type\":\"array\",\"maxItems\":256,\"desc"
    "ription\":\"Amplitude [dB]\"},\"t\":{\"additionalProperties\":false,\"type\":\"o"
    "bject\",\"patternProperties\":{\"^[0-9]+$\":{\"description\":\"one field per "
    "channel, field name is channel index\",\"$ref\":\"#/definitions/fp\"}}},\"si"
    "\":{\"maximum\":255,\"minimum\":0,\"type\":\"number\",\"description\":\"Start "
    "index (hw_start)\"},\"sr\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum"
    "\":true,\"description\":\"Sample rate [Hz]\"},\"nt\":{\"maximum\":255,\"minimum\""
    ":0,\"type\":\"integer\",\"description\":\"Number of "
    "traces\"},\"ex\":{\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' instead\",\"type\":\"object\"},\"mw\":{\"max"
    "imum\":4095,\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"descri"
    "ption\":\"Maximum weight\"},\"tbl\":{\"items\":{\"$ref\":\"#/definitions/fp_tabl"
    "e\"},\"minItems\":1,\"type\":\"array\",\"description\":\"various internal data\"}"
    ",\"ns\":{\"maximum\":4095,\"minimum\":0,\"type\":\"integer\",\"description\":\"Numb"
    "er of samples\"}},\"type\":\"object\",\"definitions\":{\"fp\":{\"description\":\"F"
    "ingerprint values\",\"properties\":{\"s\":{\"items\":{\"items\":{\"type\":\"number"
    "\"},\"minItems\":1,\"type\":\"array\",\"maxItems\":4096},\"minItems\":1,\"type\":\"a"
    "rray\",\"maxItems\":256},\"w\":{\"items\":{\"items\":{\"type\":\"number\"},\"minItem"
    "s\":5,\"type\":\"array\",\"maxItems\":5},\"minItems\":1,\"type\":\"array\",\"maxItem"
    "s\":256}},\"type\":\"object\",\"required\":[\"s\",\"w\"]},\"fp_table\":{\"desription"
    "\":\"scanner internal "
    "data\",\"properties\":{\"tc\":{\"max\":255,\"description\":\"table data type "
    "code\",\"min\":0,\"type\":\"integer\"},\"ny\":{\"max\":2048,\"description\":\"number"
    " of y entries\",\"min\":1,\"type\":\"integer\"},\"tv\":{\"items\":{\"oneOf\":[{\"$re"
    "f\":\"#/definitions/fp_table_row\"},{\"type\":\"number\"}]},\"minItems\":1,\"typ"
    "e\":\"array\",\"maxItems\":2048},\"ch\":{\"max\":255,\"description\":\"channel num"
    "ber\",\"min\":0,\"type\":\"integer\"},\"nx\":{\"max\":2048,\"description\":\"number "
    "of x entries\",\"min\":1,\"type\":\"integer\"}},\"type\":\"object\",\"required\":[\""
    "ch\",\"tc\",\"nx\",\"ny\",\"tv\"]},\"fp_table_row\":{\"items\":{\"type\":\"number\"},\"m"
    "inItems\":1,\"type\":\"array\",\"maxItems\":2048}}}"
    ,
    /* example: */
    "{\"a\":[-1.55],\"t\":{\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,1"
    "34,31],[78,86,126,134,31]]},\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[7"
    "8,86,126,134,31],[78,86,126,134,31]]}},\"si\":48,\"sr\":7959997000.0,\"nt\":"
    "128,\"mw\":31,\"tbl\":[{\"tc\":1,\"ny\":2,\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5"
    ".5]],\"ch\":0,\"nx\":5}],\"ns\":400}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"delt"
    "a\",\"content\"],\"title\":\"Reflectance Calculation "
    "Table\",\"description\":\"Lookup table for reflectance calculation based "
    "on amplitude and range\",\"properties\":{\"delta\":{\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\",\"type\":\"numb"
    "er\"},\"content\":{\"items\":{\"type\":\"number\"},\"description\":\"Correction "
    "value [dB] to be added to the amplitude\",\"maxItems\":2000,\"type\":\"array"
    "\",\"minItems\":1}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"rang"
    "es_m\",\"line_angles_deg\",\"reflectance_correction_db\"],\"title\":\"Near-ran"
    "ge reflectance correction\",\"description\":\"Range-dependent and "
    "scan-angle-dependent correction of reflectance reading\",\"properties\":{"
    "\"line_angles_deg\":{\"items\":{\"type\":\"number\"},\"description\":\"Angle [deg"
    "]\",\"type\":\"array\"},\"ranges_m\":{\"items\":{\"type\":\"number\"},\"description\""
    ":\"Range [m]\",\"type\":\"array\"},\"reflectance_correction_db\":{\"items\":{\"it"
    "ems\":{\"description\":\"columns (each value corresponds to an "
    "angle)\",\"type\":\"number\"},\"description\":\"rows (each array corresponds "
    "to a range)\",\"type\":\"array\"},\"description\":\"Near range reflectance "
    "correction in dB as a function of range over "
    "angle\",\"type\":\"array\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"ranges_m"
    "\":[0.0,1.0,2.0,3.0],\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,"
    "0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0."
    "8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,"
    "0.1,0.05,0.01]]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Scan "
    "Pattern\",\"properties\":{\"rectangular\":{\"description\":\"Rectangular Field"
    " Of View Scan Pattern\",\"properties\":{\"phi_start\":{\"maximum\":360.0,\"des"
    "cription\":\"Start phi angle in SOCS [deg]\",\"type\":\"number\",\"minimum\":0."
    "0},\"program\":{\"$ref\":\"#/definitions/program\"},\"theta_start\":{\"maximum\""
    ":180.0,\"description\":\"Start theta angle in SOCS [deg]\",\"type\":\"number\""
    ",\"minimum\":0.0},\"theta_stop\":{\"maximum\":180.0,\"description\":\"Stop "
    "theta angle in SOCS [deg]\",\"type\":\"number\",\"minimum\":0.0},\"theta_incre"
    "ment\":{\"maximum\":90.0,\"description\":\"Increment of theta angle in SOCS "
    "[deg]\",\"type\":\"number\",\"minimum\":0.0},\"phi_stop\":{\"maximum\":720.0,\"des"
    "cription\":\"Stop phi angle in SOCS [deg]\",\"type\":\"number\",\"minimum\":0.0"
    "},\"phi_increment\":{\"maximum\":90.0,\"description\":\"Increment of phi "
    "angle in SOCS [deg]\",\"type\":\"number\",\"minimum\":0.0}},\"type\":\"object\",\""
    "required\":[\"phi_start\",\"phi_stop\",\"phi_increment\",\"theta_start\",\"theta"
    "_stop\",\"theta_increment\"]},\"line\":{\"description\":\"Line Scan Pattern\",\""
    "properties\":{\"program\":{\"$ref\":\"#/definitions/program\"},\"start\":{\"maxi"
    "mum\":360.0,\"description\":\"Start angle in SOCS [deg]\",\"type\":\"number\",\""
    "minimum\":0.0},\"stop\":{\"maximum\":720.0,\"description\":\"Stop angle in "
    "SOCS [deg]\",\"type\":\"number\",\"minimum\":0.0},\"increment\":{\"maximum\":90.0"
    ",\"description\":\"Increment of angle in SOCS [deg]\",\"type\":\"number\",\"min"
    "imum\":0.0}},\"type\":\"object\",\"required\":[\"start\",\"stop\",\"increment\"]},\""
    "segments\":{\"description\":\"Segmented Line Scan "
    "Pattern\",\"properties\":{\"list\":{\"items\":{\"description\":\"Line Scan "
    "Segment\",\"properties\":{\"start\":{\"maximum\":360.0,\"description\":\"Start "
    "angle in SOCS [deg]\",\"type\":\"number\",\"minimum\":0.0},\"stop\":{\"maximum\":"
    "720.0,\"description\":\"Stop angle in SOCS [deg]\",\"type\":\"number\",\"minimu"
    "m\":0.0},\"increment\":{\"maximum\":90.0,\"description\":\"Increment of angle "
    "in SOCS [deg]\",\"type\":\"number\",\"minimum\":0.0}},\"type\":\"object\",\"requir"
    "ed\":[\"start\",\"stop\",\"increment\"]},\"type\":\"array\"},\"program\":{\"$ref\":\"#"
    "/definitions/program\"}},\"type\":\"object\",\"required\":[\"list\"]}},\"descrip"
    "tion\":\"Scan pattern "
    "description\",\"definitions\":{\"program\":{\"description\":\"Measurement prog"
    "ram\",\"properties\":{\"laser_prr\":{\"exclusiveMinimum\":false,\"description\""
    ":\"Laser Pulse Repetition Rate "
    "[Hz]\",\"type\":\"number\",\"minimum\":0},\"name\":{\"description\":\"Name of "
    "measurement program\",\"type\":\"string\"}},\"type\":\"object\",\"required\":[\"na"
    "me\"]}},\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"phi_start\":45.0,\"program\":{\"laser_prr\":100000.0,\"name"
    "\":\"High Speed\"},\"theta_start\":30.0,\"theta_stop\":130.0,\"theta_increment"
    "\":0.04,\"phi_stop\":270.0,\"phi_increment\":0.04}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Shot Information\",\"description\":\"Details about laser shot fi"
    "les\",\"properties\":{\"shot_file\":{\"properties\":{\"file_extension\":{\"descr"
    "iption\":\"Shot file extension, without the leading "
    "dot\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\",\"type\":\"string\"}},\"type\":\"object\",\"requi"
    "red\":[\"file_extension\"]}},\"type\":\"object\",\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_extension\":\"sodx\",\"file_uuid\":\"26a00815-67c0-4bff-"
    "8fe8-c577378fe663\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"acti"
    "vated\",\"filters\"],\"title\":\"Stored filters\",\"description\":\"Point "
    "filters applied in addition to the application-defined "
    "filters\",\"properties\":{\"activated\":{\"description\":\"Apply ('true') or "
    "ignore ('false') all "
    "filters\",\"type\":\"boolean\"},\"filters\":{\"items\":{\"description\":\"Point "
    "filter definition\",\"properties\":{\"title\":{\"description\":\"A short "
    "filter title (e.g. for display in a selection "
    "list)\",\"type\":\"string\"},\"activated\":{\"description\":\"Apply ('true') or "
    "ignore ('false') this "
    "filter\",\"type\":\"boolean\"},\"description\":{\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\",\"type\":\"string\"},\"filter\":{\"description\":\"The RDB filter "
    "string to apply (e.g. when reading points or index), details see "
    "documentation of function select()\",\"type\":\"string\"}},\"type\":\"object\","
    "\"required\":[\"activated\",\"title\",\"description\",\"filter\"]},\"description\""
    ":\"List of point filters\",\"type\":\"array\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"title\":\"Ignore uncertain points from "
    "MTA resolution\",\"activated\":false,\"description\":\"Ignore points with "
    "uncertain MTA zone assignment\",\"filter\":\"riegl.mta_uncertain_point == "
    "0\"},{\"title\":\"Ignore points below dynamic trigger "
    "level\",\"activated\":false,\"description\":\"Ignore points with an echo "
    "signal amplitude below the dynamic "
    "trigger\",\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\"},{\"title\":\"Ignore points outside outer "
    "AABB\",\"activated\":false,\"description\":\"Ignore points that are outside "
    "the outer AABB in BOCS\",\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\"},{\"title\":\"Ignore points inside inner "
    "AABB\",\"activated\":false,\"description\":\"Ignore points that are inside "
    "the inner AABB in BOCS\",\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"$cla"
    "ss\",\"version\",\"author\",\"timestamp\",\"system\"],\"title\":\"System "
    "Description\",\"description\":\"Details of major system components like "
    "lidar sensors, cameras and navigation "
    "devices\",\"properties\":{\"system\":{\"description\":\"The actual system "
    "description, details see documentation of RIEGL System "
    "Description\",\"type\":\"object\"},\"author\":{\"description\":\"Name of the "
    "author that created the "
    "document\",\"type\":\"string\"},\"timestamp\":{\"description\":\"Date and time "
    "of creation (e.g. 2019-06-19T13:32:10+02:00)\",\"type\":\"string\"},\"$class"
    "\":{\"description\":\"Object class name\",\"type\":\"string\",\"enum\":[\"Document"
    "\"]},\"version\":{\"description\":\"Document format "
    "version\",\"type\":\"string\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"system\":{\"details\":\"see documentation of RIEGL System "
    "Description\"},\"author\":\"RIEGL LMS GmbH, Austria\",\"timestamp\":\"2022-09-"
    "30T11:56:26+00:00\",\"$class\":\"Document\",\"version\":\"1.2.1\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Temperat"
    "ure Calculation Table\",\"description\":\"Conversion of background "
    "radiation raw values to temperatures in \\u00b0C\",\"properties\":{\"InGaAs"
    "_Si_Difference\":{\"description\":\"Conversion table for InGaAs - Si diffe"
    "rence\",\"$ref\":\"#/definitions/conversion_table\"},\"InGaAs\":{\"description"
    "\":\"Conversion table for InGaAs channel\",\"$ref\":\"#/definitions/conversi"
    "on_table\"},\"Si\":{\"description\":\"Conversion table for Si channel\",\"$ref"
    "\":\"#/definitions/conversion_table\"}},\"type\":\"object\",\"definitions\":{\"c"
    "onversion_table\":{\"properties\":{\"temperature\":{\"items\":{\"type\":\"number"
    "\"},\"description\":\"Temperature [\\u00b0C]\",\"type\":\"array\"},\"value\":{\"ite"
    "ms\":{\"type\":\"number\"},\"description\":\"LSB [1]\",\"type\":\"array\"}},\"type\":"
    "\"object\",\"required\":[\"value\",\"temperature\"]}}}"
    ,
    /* example: */
    "{\"InGaAs_Si_Difference\":{\"temperature\":[1749.977111117893,1749.9771111"
    "17893,1749.977111117893,1749.977111117893,1749.977111117893,1749.97711"
    "1117893,1744.7813348796044,1681.9971312601092,1622.3944822534868],\"val"
    "ue\":[1000.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400"
    ".0885036774805,1500.0427259132668,1600.1327555162209,1700.086977752006"
    "5,1800.0411999877924]},\"InGaAs\":{\"temperature\":[307.22196722535614,309"
    ".1153478247277,311.1188086915047,313.10025350480055,315.2137946389828,"
    "317.2172555057597,319.2207163725366,321.2021611858325,323.315702320014"
    "8],\"value\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,"
    "256.0039063692129,320.00488296151616,384.0058595538194,448.00683614612"
    "26,512.0078127384259]},\"Si\":{\"temperature\":[546.300048828125,548.81640"
    "51212026,551.3143938500972,554.0144257850053,556.604252334815,559.2124"
    "464488079,561.8022729986177,564.4104671126105,567.0002936624203],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"epoc"
    "h\",\"source\"],\"title\":\"Time Base\",\"description\":\"Base of timestamps "
    "(epoch)\",\"properties\":{\"system\":{\"description\":\"Time system (time stan"
    "dard)\",\"type\":\"string\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"]},\"source\":{\"desc"
    "ription\":\"Timestamp source\",\"type\":\"string\",\"enum\":[\"unknown\",\"RTC\",\"G"
    "NSS\"]},\"epoch\":{\"description\":\"Date and time of timestamp '0' as "
    "proposed by RFC 3339 (e.g. "
    "2015-10-27T00:00:00+01:00).\",\"type\":\"string\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"system\":\"UTC\",\"source\":\"GNSS\",\"epoch\":\"2015-10-27T00:00:00+00:00\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"time"
    "_interval\",\"navigation_frame\"],\"title\":\"Trajectory "
    "Information\",\"description\":\"Details about position+orientation "
    "files\",\"properties\":{\"location\":{\"description\":\"Project location, e.g."
    " city/state/country\",\"type\":\"string\"},\"software\":{\"description\":\"Softw"
    "are that calculated the trajectory (this may be the same or different "
    "software than the one that created the "
    "file)\",\"type\":\"string\"},\"navigation_frame\":{\"description\":\"Navigation "
    "frame (NED: North-East-Down, ENU: East-North-Up)\",\"type\":\"string\",\"enu"
    "m\":[\"unknown\",\"NED\",\"ENU\"]},\"company\":{\"description\":\"Company "
    "name\",\"type\":\"string\"},\"device\":{\"description\":\"Navigation device, "
    "e.g. "
    "name/type/serial\",\"type\":\"string\"},\"project\":{\"description\":\"Project "
    "name\",\"type\":\"string\"},\"time_interval\":{\"description\":\"Time interval "
    "statistics\",\"properties\":{\"minimum\":{\"description\":\"Minimum time "
    "interval [s]\",\"type\":\"number\"},\"std_dev\":{\"description\":\"Standard "
    "deviation of intervals "
    "[s]\",\"type\":\"number\"},\"maximum\":{\"description\":\"Maximum time interval "
    "[s]\",\"type\":\"number\"},\"average\":{\"description\":\"Average time interval "
    "[s]\",\"type\":\"number\"}},\"type\":\"object\",\"required\":[\"minimum\",\"average\""
    ",\"maximum\",\"std_dev\"]},\"settings\":{\"description\":\"Settings used to "
    "calculate the trajectory (descriptive "
    "text)\",\"type\":\"string\"},\"field_of_application\":{\"description\":\"Field "
    "of application\",\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"M"
    "LS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"]}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"location\":\"Horn\",\"software\":\"Navigation Software "
    "XYZ\",\"navigation_frame\":\"NED\",\"company\":\"RIEGL LMS\",\"device\":\"IMU "
    "Model 12/1, Serial# 12345\",\"project\":\"Campaign 3\",\"time_interval\":{\"mi"
    "nimum\":0.00500032,\"std_dev\":5.51e-07,\"maximum\":0.005004883,\"average\":0"
    ".00500053},\"settings\":\"default\",\"field_of_application\":\"MLS\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ttip"
    "_version\",\"num_channel\",\"ext_channel\",\"ext_signal\",\"ext_delay\",\"ext_su"
    "bdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time\",\"dmi_max_time\",\"dmi_"
    "dist_per_tick\",\"channel\",\"output_descr\",\"input_descr\",\"output_usage\",\""
    "input_usage\",\"out_polarity\",\"out_duration\",\"out_interval\",\"out_delay\","
    "\"out_num_pulses\",\"in_polarity\",\"in_min_duration\",\"in_max_duration\",\"in"
    "_max_delay\"],\"title\":\"TTIP "
    "Configuration\",\"description\":\"Trigger-Timestamping-Unit/IP "
    "configuration\",\"properties\":{\"ext_delay\":{\"description\":\"external "
    "trigger, time delay [0.1 msec]\",\"type\":\"integer\",\"minimum\":0},\"input_d"
    "escr\":{\"description\":\"descriptive "
    "string\",\"type\":\"string\"},\"dmi_max_time\":{\"description\":\"dmi, maximum "
    "time interval between trigger events [0.1 "
    "msec]\",\"type\":\"integer\",\"minimum\":0},\"ext_signal\":{\"description\":\"0 .."
    " use input signal, 1 .. use output signal of "
    "channel\",\"type\":\"integer\",\"minimum\":0},\"channel\":{\"description\":\"ID of"
    " input/output channel\",\"type\":\"integer\",\"minimum\":0},\"out_polarity\":{\""
    "description\":\"0 .. positive edge, 1 .. negative "
    "edge\",\"type\":\"integer\",\"minimum\":0},\"in_polarity\":{\"description\":\"0 .."
    " positive edge, 1 .. negative edge\",\"type\":\"integer\",\"minimum\":0},\"in_"
    "max_duration\":{\"description\":\"stops measurement of pulse duration of "
    "input signal [0.1 msec]\",\"type\":\"integer\",\"minimum\":0},\"out_duration\":"
    "{\"description\":\"output pulse duration [0.1 msec]\",\"type\":\"integer\",\"mi"
    "nimum\":0},\"in_max_delay\":{\"description\":\"maximum delay to output pulse"
    " before fake event is generated [0.1 msec], zero indicates that no "
    "fake events are generated\",\"type\":\"integer\",\"minimum\":0},\"output_descr"
    "\":{\"description\":\"descriptive "
    "string\",\"type\":\"string\"},\"ext_channel\":{\"description\":\"ID of channel "
    "used as external trigger input, 32 indicates none\",\"type\":\"integer\",\"m"
    "inimum\":0},\"ext_subdivider\":{\"description\":\"reduces the frequency, "
    "default "
    "1\",\"type\":\"integer\",\"minimum\":0},\"dmi_min_time\":{\"description\":\"dmi, "
    "minimum time interval between trigger events [0.1 msec]\",\"type\":\"integ"
    "er\",\"minimum\":0},\"dmi_dist_per_tick\":{\"description\":\"dmi, distance per"
    " tick, just informative "
    "[m]\",\"type\":\"number\"},\"in_min_duration\":{\"description\":\"input signals "
    "with smaller pulse durations are ignored [0.1 msec]\",\"type\":\"integer\","
    "\"minimum\":0},\"ext_bitmask\":{\"description\":\"defines which of the "
    "internal pulse generators are to be "
    "started\",\"type\":\"integer\",\"minimum\":0},\"input_usage\":{\"description\":\"0"
    " .. deactivated, 1 .. just detecting and timestamping\",\"type\":\"integer"
    "\",\"minimum\":0},\"num_channel\":{\"description\":\"number of input/output ch"
    "annels\",\"type\":\"integer\",\"minimum\":0},\"out_interval\":{\"description\":\"o"
    "utput pulse interval [0.1 msec]\",\"type\":\"integer\",\"minimum\":0},\"ttip_v"
    "ersion\":{\"description\":\"following main.sub.ss.sss\",\"type\":\"integer\",\"m"
    "inimum\":0},\"output_usage\":{\"description\":\"0 .. no output, 1 .. output "
    "derived from internal clock, 2 .. output derived from dmi, 3 .. output"
    " derived from external signal, 4 .. output static low, 5 .. output "
    "static "
    "high\",\"type\":\"integer\",\"minimum\":0},\"dmi_incr\":{\"description\":\"dmi, "
    "increment in "
    "ticks\",\"type\":\"integer\"},\"out_num_pulses\":{\"description\":\"number of "
    "output pulses to be generated, 0 .. infinite\",\"type\":\"integer\",\"minimu"
    "m\":0},\"out_delay\":{\"description\":\"output pulse initial delay after "
    "start [0.1 msec]\",\"type\":\"integer\",\"minimum\":0}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"ext_delay\":0,\"input_descr\":\"Port 1 - Exposure\",\"dmi_max_time\":0,\"ext"
    "_signal\":0,\"channel\":0,\"out_polarity\":0,\"in_polarity\":0,\"in_max_durati"
    "on\":10000,\"out_duration\":300,\"in_max_delay\":9990,\"output_descr\":\"Port "
    "1 - Trigger\",\"ext_channel\":32,\"ext_subdivider\":1,\"dmi_min_time\":0,\"dmi"
    "_dist_per_tick\":0.0,\"in_min_duration\":0,\"ext_bitmask\":0,\"input_usage\":"
    "1,\"num_channel\":9,\"out_interval\":10000,\"ttip_version\":1,\"output_usage\""
    ":1,\"dmi_incr\":0,\"out_num_pulses\":1,\"out_delay\":0}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Vertex Information\",\"description\":\"Details about vertex file"
    "\",\"properties\":{\"vertex_file\":{\"properties\":{\"file_extension\":{\"descri"
    "ption\":\"Vertex file extension, without the leading "
    "dot\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\",\"type\":\"string\"}},\"type\":\"object\",\"requi"
    "red\":[\"file_extension\"]}},\"type\":\"object\",\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_extension\":\"vtx\",\"file_uuid\":\"51534d95-d71f-4f36"
    "-ae1a-3e63a21fd1c7\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Voxel "
    "Information\",\"description\":\"Details about the voxels contained in the "
    "file\",\"type\":\"object\",\"definitions\":{\"voxel_size_cubic\":{\"$ref\":\"#/def"
    "initions/edge_length\",\"type\":\"number\"},\"voxel_type\":{\"default\":\"centro"
    "id\",\"description\":\"Whether a point in a voxel represents its center or"
    " its centroid. If type is <tt>index</tt> there is no point but only an"
    " integer voxel index.\",\"enum\":[\"center\",\"centroid\",\"index\"]},\"edge_len"
    "gth\":{\"minimum\":0,\"description\":\"Length of voxel edge [m].\",\"type\":\"nu"
    "mber\",\"exclusiveMinimum\":true},\"voxel_size\":{\"items\":{\"$ref\":\"#/defini"
    "tions/edge_length\"},\"description\":\"Size of voxels.\",\"maxItems\":3,\"type"
    "\":\"array\",\"minItems\":3},\"voxel_origin_point\":{\"items\":{\"type\":\"number\""
    "},\"description\":\"Origin point for all voxel indices in voxel CRS.\",\"ma"
    "xItems\":3,\"type\":\"array\",\"minItems\":3},\"shape_thresholds\":{\"descriptio"
    "n\":\"Thresholds used to compute the voxel's shape_id "
    "value.\",\"properties\":{\"line\":{\"minimum\":1,\"description\":\"If the "
    "biggest eigenvalue is bigger than the median eigenvalue * "
    "line_threshold, the voxel is considered a line.\",\"type\":\"number\",\"excl"
    "usiveMinimum\":true},\"plane\":{\"exclusiveMinimum\":true,\"maximum\":1,\"excl"
    "usiveMaximum\":true,\"description\":\"If the smallest eigenvalue is "
    "smaller than the median eigenvalue * plane_threshold, the voxel is "
    "considered a plane.\",\"type\":\"number\",\"minimum\":0}},\"type\":\"object\",\"re"
    "quired\":[\"plane\",\"line\"]},\"voxel_origin_enum\":{\"default\":\"corner\",\"des"
    "cription\":\"Defines whether the voxel's center or a corner is placed on"
    " CRS origin <tt>(0/0/0)</tt>.\",\"enum\":[\"center\",\"corner\"]}},\"oneOf\":[{"
    "\"properties\":{\"voxel_origin\":{\"$ref\":\"#/definitions/voxel_origin_enum\""
    "},\"size\":{\"description\":\"Size of voxels in file coordinate system.\",\"o"
    "neOf\":[{\"$ref\":\"#/definitions/voxel_size\"},{\"$ref\":\"#/definitions/voxe"
    "l_size_cubic\"}]},\"shape_thresholds\":{\"$ref\":\"#/definitions/shape_thres"
    "holds\"},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"}},\"additionalP"
    "roperties\":false,\"required\":[\"size\",\"voxel_origin\",\"voxel_type\"]},{\"pr"
    "operties\":{\"reference_point\":{\"items\":{\"maximum\":180,\"minimum\":-180,\"t"
    "ype\":\"number\"},\"description\":\"Point in WGS84 geodetic decimal degree "
    "(EPSG:4326) that was used to compute the projection distortion "
    "parameters. The coefficient order is latitude, longitude. Only voxels "
    "with corresponding geo_tag, voxel_size and reference_point can be "
    "reliably processed together. This entry is available for voxel files "
    "in projected CRS only.\",\"maxItems\":2,\"type\":\"array\",\"minItems\":2},\"vox"
    "el_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"size_llcs\":{\"description"
    "\":\"Size of voxels in a locally levelled cartesian coordinate system "
    "(xyz). This is only used for voxels based on a map projection.\",\"$ref\""
    ":\"#/definitions/voxel_size\"},\"voxel_origin\":{\"oneOf\":[{\"$ref\":\"#/defin"
    "itions/voxel_origin_enum\"},{\"description\":\"The base point of the voxel"
    " grid. Used together with <tt>voxel_size</tt> and <tt>voxel_index</tt>"
    " to compute actual point coordinates.\",\"$ref\":\"#/definitions/voxel_ori"
    "gin_point\"}]},\"size\":{\"description\":\"Size of voxels in file coordinate"
    " system.\",\"$ref\":\"#/definitions/voxel_size\"},\"shape_thresholds\":{\"$ref"
    "\":\"#/definitions/shape_thresholds\"}},\"additionalProperties\":false,\"req"
    "uired\":[\"reference_point\",\"size_llcs\",\"size\",\"voxel_origin\",\"voxel_typ"
    "e\"]}]}"
    ,
    /* example: */
    "{\"reference_point\":[48,16],\"voxel_type\":\"centroid\",\"size_llcs\":[0.5156"
    "575252891171,0.5130835356683303,0.5143705304787237],\"voxel_origin\":\"co"
    "rner\",\"size\":[0.5971642834779395,0.5971642834779395,0.5143705304787237"
    "],\"shape_thresholds\":{\"line\":6,\"plane\":0.16}}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"num_"
    "shots\",\"mta_zone\"],\"title\":\"Waveform Averaging "
    "Settings\",\"description\":\"Settings for waveform "
    "averaging\",\"properties\":{\"mta_zone\":{\"description\":\"Fixed MTA zone for"
    " averaging.\",\"type\":\"integer\",\"minimum\":1},\"trim\":{\"default\":0,\"maximu"
    "m\":0.5,\"description\":\"Percentage for robust averaging.\",\"type\":\"number"
    "\",\"minimum\":0},\"num_shots\":{\"description\":\"Number of consecutive shots"
    " to be used for "
    "averaging.\",\"type\":\"integer\",\"minimum\":1}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"mta_zone\":1,\"trim\":0.05,\"num_shots\":7}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"samp"
    "le_block_file\",\"sample_data_files\"],\"title\":\"Waveform "
    "Information\",\"description\":\"Details about waveform files\",\"properties\""
    ":{\"sample_data_files\":{\"items\":{\"properties\":{\"laser_wavelength\":{\"min"
    "imum\":0,\"description\":\"Laser wavelength in meters (0 = unknown)\",\"type"
    "\":\"number\",\"exclusiveMinimum\":false},\"file_extension\":{\"description\":\""
    "Sample data file extension, without the leading "
    "dot\",\"type\":\"string\"},\"channel_name\":{\"description\":\"Sample block "
    "channel name\",\"type\":\"string\"},\"channel\":{\"exclusiveMinimum\":false,\"ma"
    "ximum\":255,\"exclusiveMaximum\":false,\"description\":\"Sample block "
    "channel number (255 = invalid)\",\"type\":\"integer\",\"minimum\":0},\"sample_"
    "bits\":{\"exclusiveMinimum\":false,\"maximum\":32,\"exclusiveMaximum\":false,"
    "\"description\":\"Bitwidth of samples (e.g. 10 bit, 12 bit)\",\"type\":\"inte"
    "ger\",\"minimum\":0},\"sample_interval\":{\"minimum\":0,\"description\":\"Sampli"
    "ng interval in seconds\",\"type\":\"number\",\"exclusiveMinimum\":false},\"del"
    "ta_st\":{\"description\":\"reserved\",\"type\":\"number\"},\"file_uuid\":{\"descri"
    "ption\":\"File's Universally Unique Identifier (RFC 4122)\",\"type\":\"strin"
    "g\"}},\"type\":\"object\",\"required\":[\"channel\",\"channel_name\",\"sample_inte"
    "rval\",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_extension\"]},\""
    "type\":\"array\"},\"range_offset_m\":{\"description\":\"Calibrated device "
    "specific range offset for waveform analysis by system response fitting"
    " in meters.\",\"type\":\"number\"},\"sample_block_file\":{\"properties\":{\"file"
    "_extension\":{\"description\":\"Sample block file extension, without the "
    "leading dot\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"File's "
    "Universally Unique Identifier (RFC 4122)\",\"type\":\"string\"}},\"type\":\"ob"
    "ject\",\"required\":[\"file_extension\"]},\"range_offset_waveform_samples_m\""
    ":{\"description\":\"Calibrated device specific range offset for waveform "
    "samples in meters.\",\"type\":\"number\"}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"range_offset_waveform_samples_m \":7.283,\"sample_block_file\":{\"file_e"
    "xtension\":\"sbx\",\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\"},\"r"
    "ange_offset_m\":3.1415,\"sample_data_files\":[{\"laser_wavelength\":0,\"file"
    "_extension\":\"sp0\",\"channel_name\":\"high_power\",\"channel\":0,\"sample_bits"
    "\":12,\"sample_interval\":1.00503e-09,\"delta_st\":0,\"file_uuid\":\"da084413-"
    "e3e8-4655-a122-071de8490d8e\"},{\"laser_wavelength\":0,\"file_extension\":\""
    "sp1\",\"channel_name\":\"low_power\",\"channel\":1,\"sample_bits\":12,\"sample_i"
    "nterval\":1.00503e-09,\"delta_st\":0,\"file_uuid\":\"93585b5e-5ea9-43a1-947b"
    "-e7ba3be642d2\"},{\"laser_wavelength\":0,\"file_extension\":\"sp5\",\"channel_"
    "name\":\"wwf\",\"channel\":5,\"sample_bits\":12,\"sample_interval\":1.00503e-09"
    ",\"delta_st\":0,\"file_uuid\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3a0\"}]}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Waveform Settings\",\"items\":{\"properties\":{\"pass_rng_less\":{\""
    "description\":\"Threshold for range less than "
    "[m]\",\"type\":\"number\"},\"smart_enabled\":{\"description\":\"Smart waveform "
    "output enabled\",\"type\":\"boolean\"},\"sbl_name\":{\"description\":\"Name of "
    "sample block, e.g.: wfm, "
    "wwf\",\"type\":\"string\"},\"channel_idx_mask\":{\"description\":\"Bit mask for "
    "channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = Bit1,"
    " ...\",\"type\":\"integer\"},\"pass_dev_less\":{\"description\":\"Threshold for "
    "deviation less than "
    "[1]\",\"type\":\"integer\"},\"pass_dev_greater\":{\"description\":\"Threshold "
    "for deviation greater than "
    "[1]\",\"type\":\"integer\"},\"logic_expression\":{\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\",\"type\":\"string\"},\"pass_ampl_greater\":{\"description\":\"Threshold"
    " for amplitude greater than "
    "[dB]\",\"type\":\"number\"},\"pass_rng_greater\":{\"description\":\"Threshold "
    "for range greater than "
    "[m]\",\"type\":\"number\"},\"pass_ampl_less\":{\"description\":\"Threshold for "
    "amplitude less than "
    "[dB]\",\"type\":\"number\"},\"enabled\":{\"description\":\"Waveform output enabl"
    "ed\",\"type\":\"boolean\"}},\"type\":\"object\",\"required\":[\"sbl_name\",\"enabled"
    "\",\"channel_idx_mask\"]},\"description\":\"Scanner settings for waveform ou"
    "tput\",\"type\":\"array\",\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\"}"
    ,
    /* example: */
    "[{\"pass_rng_less\":13.11,\"smart_enabled\":true,\"sbl_name\":\"wfm\",\"channel"
    "_idx_mask\":11,\"pass_ampl_greater\":1.0,\"pass_rng_greater\":9.27,\"pass_am"
    "pl_less\":5.0,\"enabled\":true},{\"sbl_name\":\"wwf\",\"channel_idx_mask\":32,\""
    "enabled\":false}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"resu"
    "lt\",\"filter\",\"settings\"],\"title\":\"Window "
    "Analysis\",\"description\":\"Window analysis data estimated from scandata "
    "and resulting filter parameters\",\"properties\":{\"settings\":{\"properties"
    "\":{\"range\":{\"properties\":{\"additive_value\":{\"type\":\"number\"},\"sigma_fa"
    "ctor\":{\"type\":\"number\"}},\"type\":\"object\",\"required\":[\"sigma_factor\",\"a"
    "dditive_value\"]},\"amplitude\":{\"properties\":{\"additive_value\":{\"type\":\""
    "number\"},\"sigma_factor\":{\"type\":\"number\"}},\"type\":\"object\",\"required\":"
    "[\"sigma_factor\",\"additive_value\"]}},\"type\":\"object\",\"required\":[\"range"
    "\",\"amplitude\"]},\"result\":{\"properties\":{\"timestamp\":{\"items\":{\"type\":\""
    "number\"},\"description\":\"[s]\",\"type\":\"array\"},\"amplitude_sigma\":{\"items"
    "\":{\"type\":\"number\"},\"description\":\"[dB]\",\"type\":\"array\"},\"amplitude_me"
    "an\":{\"items\":{\"type\":\"number\"},\"description\":\"[dB]\",\"type\":\"array\"},\"r"
    "ange_sigma\":{\"items\":{\"type\":\"number\"},\"description\":\"[m]\",\"type\":\"arr"
    "ay\"},\"angle\":{\"items\":{\"type\":\"number\"},\"description\":\"[deg]\",\"type\":\""
    "array\"},\"range_mean\":{\"items\":{\"type\":\"number\"},\"description\":\"[m]\",\"t"
    "ype\":\"array\"},\"amplitude_offset\":{\"items\":{\"type\":\"number\"},\"descripti"
    "on\":\"[dB]\",\"type\":\"array\"}},\"type\":\"object\",\"required\":[\"angle\",\"range"
    "_mean\",\"range_sigma\",\"amplitude_mean\",\"amplitude_sigma\",\"amplitude_off"
    "set\"]},\"filter\":{\"properties\":{\"range_max\":{\"items\":{\"type\":\"number\"},"
    "\"description\":\"[m]\",\"type\":\"array\"},\"amplitude_max\":{\"items\":{\"type\":\""
    "number\"},\"description\":\"[dB]\",\"type\":\"array\"},\"angle\":{\"items\":{\"type\""
    ":\"number\"},\"description\":\"[deg]\",\"type\":\"array\"},\"range_min\":{\"items\":"
    "{\"type\":\"number\"},\"description\":\"[m]\",\"type\":\"array\"}},\"type\":\"object\""
    ",\"required\":[\"angle\",\"range_min\",\"range_max\",\"amplitude_max\"]}},\"type\""
    ":\"object\"}"
    ,
    /* example: */
    "{\"settings\":{\"range\":{\"additive_value\":0.1,\"sigma_factor\":8},\"amplitud"
    "e\":{\"additive_value\":1.0,\"sigma_factor\":4}},\"result\":{\"timestamp\":[408"
    ".4441,411.4443],\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816,0.428"
    "3583,0.4362353,0.4315141,0.4373984,0.4472798,0.4346001,0.4345487,0.454"
    "0681],\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179926,5.097782,5"
    ".116479,5.051756,4.983473,5.007885,5.002441,4.982],\"range_sigma\":[0.01"
    "869652,0.02151435,0.01747969,0.01918765,0.01945776,0.01934862,0.019553"
    "29,0.02225589,0.02229977,0.01899122,0.02009433],\"angle\":[14.9,15.0,15."
    "1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\"range_mean\":[0.1105621,0.1"
    "079564,0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.10"
    "51523,0.1058445,0.1031261],\"amplitude_offset\":[1.9,1.9]},\"filter\":{\"ra"
    "nge_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43,0.431,0.431,0"
    ".432],\"amplitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8"
    ",7.78],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9"
    "],\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,"
    "-0.223,-0.225,-0.227]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ampl"
    "itude\",\"range\",\"slices\"],\"title\":\"Window Echo "
    "Correction\",\"description\":\"Correction parameters for window glass "
    "echoes\",\"properties\":{\"slices\":{\"items\":{\"description\":\"Window echo "
    "correction parameter slice\",\"properties\":{\"table\":{\"items\":{\"items\":{\""
    "items\":{\"description\":\"Table cell (item 0: amplitude in dB, 1: range "
    "in m, 2: flags)\",\"type\":\"number\"},\"description\":\"Table column (= range"
    " axis)\",\"maxItems\":3,\"type\":\"array\",\"minItems\":3},\"description\":\"Table"
    " row (= amplitude "
    "axis)\",\"type\":\"array\",\"minItems\":1},\"description\":\"Correction table "
    "(dimension defined by the 'amplitude' and 'range' objects)\",\"type\":\"ar"
    "ray\",\"minItems\":1},\"amplitude\":{\"description\":\"Window echo amplitude "
    "of slice in dB\",\"type\":\"number\"}},\"type\":\"object\",\"required\":[\"amplitu"
    "de\",\"table\"]},\"type\":\"array\"},\"range\":{\"description\":\"Range axis of "
    "correction table\",\"properties\":{\"entries\":{\"description\":\"Number of "
    "range entries\",\"type\":\"integer\",\"minimum\":1},\"minimum\":{\"maximum\":2.0,"
    "\"description\":\"Minimum range in m\",\"type\":\"number\",\"minimum\":-2.0},\"ma"
    "ximum\":{\"maximum\":2.0,\"description\":\"Maximum range in m\",\"type\":\"numbe"
    "r\",\"minimum\":-2.0}},\"type\":\"object\",\"required\":[\"minimum\",\"maximum\",\"e"
    "ntries\"]},\"amplitude\":{\"description\":\"Amplitude axis of correction "
    "table\",\"properties\":{\"entries\":{\"description\":\"Number of amplitude ent"
    "ries\",\"type\":\"integer\",\"minimum\":1},\"minimum\":{\"description\":\"Minimum "
    "amplitude in "
    "dB\",\"type\":\"number\",\"minimum\":0.0},\"maximum\":{\"description\":\"Maximum "
    "amplitude in dB\",\"type\":\"number\",\"minimum\":0.0}},\"type\":\"object\",\"requ"
    "ired\":[\"minimum\",\"maximum\",\"entries\"]}},\"type\":\"object\"}"
    ,
    /* example: */
    "{\"slices\":[{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\""
    ":1.5},{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":2.0}"
    "],\"range\":{\"entries\":128,\"minimum\":-1.5060822940732335,\"maximum\":1.506"
    "0822940732335},\"amplitude\":{\"entries\":128,\"minimum\":2,\"maximum\":20}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
